@@ -13,16 +13,16 @@ def main():
     with socketserver.TCPServer(('127.0.0.1', PORT), Handler) as run:
         if name == 'posix':
             try:
-                if webbrowser.open(f'http://127.0.0.1:{PORT}/index.html') == True:
+                if webbrowser.open(f'http://127.0.0.1:{PORT}/') == True:
                     pass
                 else:
                     system(
-                        f'termux-open-url http://127.0.0.1:{PORT}/index.html')
+                        f'termux-open-url http://127.0.0.1:{PORT}/')
             except:
                 print(
-                    f"Gagal membuka alamat http://127.0.0.1:{PORT}/index.html")
+                    f"Gagal membuka alamat http://127.0.0.1:{PORT}/")
         else:
-            webbrowser.open(f'http://127.0.0.1:{PORT}/index.html')
+            webbrowser.open(f'http://127.0.0.1:{PORT}/')
         try:
             print('CTRL + C , untuk kaluar!')
             run.serve_forever()
